import { Component, OnInit } from '@angular/core';
import { SessioService } from 'src/app/services/sessio.service';
import { ActivitatService } from 'src/app/services/activitat.service';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-activitat',
  templateUrl: './activitat.page.html',
  styleUrls: ['./activitat.page.scss'],
})
export class ActivitatPage implements OnInit {
  activitat: any = [];
  auxActivitat = 0;
  open = true;
  materials: any[] = [
    { material: 'Paper', color: 'primary' },
    { material: 'Plàstic', color: 'warning' },
    { material: 'Vidre', color: 'success' },
    { material: 'Varis', color: 'danger' },
  ];

  constructor(
    private router: Router,
    private sessioService: SessioService,
    private activitatService: ActivitatService,
    private toastController: ToastController
  ) {}

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  ionViewWillEnter() {
    this.auxActivitat = 0;
    this.recuperaDades();
  }

  /*Demana a l'API la informació referent a cada material.
  Guarda les dades a l'array d'activitat per a la seva posterior visualització.*/

  recuperaDades() {
    if (this.auxActivitat < this.materials.length) {
      this.activitatService
        .postActivitat(this.materials[this.auxActivitat])
        .subscribe((res) => {
          if (res.status === '1') {
            this.activitat.splice(this.auxActivitat, 0, res.dades);
            this.auxActivitat++;
            this.presentToast(res.missatge);
            this.recuperaDades();
          }
        });
    }
  }

  //Funció encarregada d'obrir i tancar els diferents desplegables.

  obrirDesplegable(i: any) {
    this.open = true;
    this.materials[i].open = !this.materials[i].open;
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
}
