import { Component, OnInit } from '@angular/core';
import { BarcodeScanner } from '@ionic-native/barcode-scanner/ngx';
import { ProductesService } from 'src/app/services/productes.service';
import { TemporalService } from 'src/app/services/temporal.service';
import { TokenInterceptorService } from 'src/app/services/token-interceptor.service';
import { SessioService } from 'src/app/services/sessio.service';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-bar-code',
  templateUrl: './bar-code.page.html',
  styleUrls: ['./bar-code.page.scss'],
})
export class BarCodePage implements OnInit {
  llistaTemp = false;

  constructor(
    private barcodeScanner: BarcodeScanner,
    private prodService: ProductesService,
    private tempService: TemporalService,
    private tokenInterceptor: TokenInterceptorService,
    private sessioService: SessioService,
    private router: Router,
    private toastController: ToastController
  ) {}

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  //Crida a l'API i retorna els productes en iniciar la pàgina.
  ionViewWillEnter() {
    this.tempService.getProductes().subscribe((res) => {
      if (res.status === '1' && res.valor === '0') {
        console.log(res.missatge);
        this.llistaTemp = false;
      } else {
        this.llistaTemp = true;
      }
    });
  }

  //Funció que obre la càmera i escaneja el codi
  scan() {
    this.barcodeScanner
      .scan()
      .then((barcodeData) => {
        console.log('Barcode data', barcodeData);
        this.prodService.codi = barcodeData.text;
        if (barcodeData.cancelled) {
          this.router.navigate(['bar-code']);
        } else {
          this.router.navigate(['recicla']);
        }
      })
      .catch((err) => {
        this.prodService.codi = '8437008459059';
        this.router.navigate(['recicla']);
        console.log('Error', err);
      });
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
}
