import { Component, OnInit } from '@angular/core';
import { SessioService } from 'src/app/services/sessio.service';
import { ActivitatService } from 'src/app/services/activitat.service';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';
import { TaxesService } from 'src/app/services/taxes.service';

@Component({
  selector: 'app-bonificacions',
  templateUrl: './bonificacions.page.html',
  styleUrls: ['./bonificacions.page.scss'],
})
export class BonificacionsPage implements OnInit {
  taxes: any[] = [];
  valor = 0;
  totalTaxes = 0;
  descompteTotal = '';
  quotaFinal = '';
  bonificacions: any = [];
  auxBonificacions = 0;
  open = true;
  materials: any[] = [
    { material: 'Paper', color: 'primary' },
    { material: 'Plàstic', color: 'warning' },
    { material: 'Vidre', color: 'success' },
    { material: 'Varis', color: 'danger' },
  ];

  constructor(
    private router: Router,
    private sessioService: SessioService,
    private activitatService: ActivitatService,
    private taxesService: TaxesService,
    private toastController: ToastController
  ) {}

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  ionViewWillEnter() {
    this.auxBonificacions = 0;
    this.valor = 0;
    this.totalTaxes = 0;
    this.taxesUsuari();
  }

  //Funció encarregada de demanar les taxes corresponents a l'usuari.

  taxesUsuari() {
    this.taxesService.postTaxes().subscribe((res) => {
      if (res.status === '1') {
        if (res.dades === undefined) {
          const buit = [{ taxa: '0' }];
          this.taxes = buit;
          this.recuperaDades();
        } else {
          this.taxes = res.dades;
          this.presentToast(res.missatge);
          //console.log(res);
          this.recuperaDades();
        }
      }
    });
  }

  /*Demana a l'API la informació referent a cada material.
  Guarda les dades a l'array d'activitat per a la seva posterior visualització.*/

  recuperaDades() {
    if (this.auxBonificacions < this.materials.length) {
      this.activitatService
        .postActivitat(this.materials[this.auxBonificacions])
        .subscribe((res) => {
          if (res.status === '1') {
            //Si la resposta és undefined guarda un array amb un objecte buit.
            if (res.dades === undefined) {
              const buit = [{}];
              this.bonificacions.splice(this.auxBonificacions, 0, buit);
              this.auxBonificacions++;
              this.recuperaDades();
              this.presentToast(res.missatge);
              //console.log(this.bonificacions);

              //Si no, guarda la resposta a l'array bonificacions.
            } else {
              this.bonificacions.splice(this.auxBonificacions, 0, res.dades);
              this.auxBonificacions++;
              this.recuperaDades();
              this.presentToast(res.missatge);
              //console.log(this.bonificacions);
            }
          }
        });
    } else {
      this.descompte();
      this.totalQuota();
    }
  }

  //Funció que suma els diferents valors dels materials per aplicar el descompte.

  descompte() {
    for (let i = 0; i < this.materials.length; i++) {
      //console.log(i, this.activitat[i]);
      for (let j = 0; j < this.bonificacions[i].length; j++) {
        console.log(j, this.bonificacions[i][j].valor);

        //Si la resposta.valor és undefined li assigna un 0 a valor.
        if (this.bonificacions[i][j].valor === undefined) {
          this.valor = 0 + this.valor;
          //Si no, li assigna el valor retornat a la resposta.
        } else {
          this.valor = parseFloat(this.bonificacions[i][j].valor) + this.valor;
        }
      }
      this.descompteTotal = this.valor.toFixed(2);
      console.log(this.valor);
    }
  }

  //Funció encarregada de sumar les diferents taxes i calcular el valor final amb el descompte.

  totalQuota() {
    let quota = 0;
    for (let i = 0; i < this.taxes.length; i++) {
      console.log(i);

      this.totalTaxes = parseFloat(this.taxes[i].taxa) + this.totalTaxes;
    }
    quota = this.totalTaxes - this.valor;
    this.quotaFinal = quota.toFixed(2);
  }

  //Funció encarregada d'obrir i tancar els diferents desplegables.

  obrirDesplegable(i: any) {
    this.open = true;
    this.materials[i].open = !this.materials[i].open;
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
}
