import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';
import { ContacteService } from 'src/app/services/contacte.service';

@Component({
  selector: 'app-contacte',
  templateUrl: './contacte.page.html',
  styleUrls: ['./contacte.page.scss'],
})
export class ContactePage implements OnInit {
  form: any = FormBuilder;

  constructor(
    private formBuilder: FormBuilder,
    private contacteService: ContacteService,
    private router: Router,
    private toastController: ToastController
  ) {
    this.buildForm();
  }

  ngOnInit() {}

  //Funció que envia el formulari.
  save(event: Event) {
    event.preventDefault();
    if (this.form.valid) {
      const value = this.form.value;
      //console.log(value);
      this.contacteService.postContacte(value).subscribe((res) => {
        if (res) {
          this.presentToast(res.missatge);
          console.log(res.missatge);
          this.buildForm();
        }
      });
    }
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }

  //Funció que crea el formulari i les seves validacions.
  private buildForm() {
    this.form = this.formBuilder.group({
      nom: ['', [Validators.required, Validators.maxLength(20)]],
      cognom: ['', [Validators.required, Validators.maxLength(20)]],
      correu: ['', [Validators.required, Validators.email]],
      missatge: ['', [Validators.required]],
    });
  }
}
