import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { ProductesService } from '../../services/productes.service';
import { TemporalService } from 'src/app/services/temporal.service';
import { CrearProducteService } from 'src/app/services/crear-producte.service';
import { Router } from '@angular/router';
import { SessioService } from 'src/app/services/sessio.service';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-crear-producte',
  templateUrl: './crear-producte.page.html',
  styleUrls: ['./crear-producte.page.scss'],
})
export class CrearProductePage implements OnInit {
  form: any = FormGroup;
  codi = '';

  constructor(
    private formBuilder: FormBuilder,
    private prodService: ProductesService,
    private tempService: TemporalService,
    private crearService: CrearProducteService,
    private sessioService: SessioService,
    private router: Router,
    private toastController: ToastController
  ) {
    //Crida a la funció per crear el formulari.
    this.buildForm();
  }

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  //Recupera el codi del servei abans de carregar la pàgina.
  ionViewWillEnter() {
    this.codi = this.prodService.codi;
    this.form.patchValue({
      codi: this.codi,
    });
    //console.log(this.codi);
  }

  //Buida el formulari i torna a la pàgina bar-code amb el botó cancel·lar.
  returnScan() {
    this.router.navigate(['bar-code']);
    this.buildForm();
  }

  //Funció que envia el formulari omplert prèviament per crear un nou producte.

  save(event: Event) {
    event.preventDefault();
    if (this.form.valid) {
      const value = this.form.value;
      value.pes = value.pes / 1000;
      //console.log(value);
      this.crearService.crearProducte(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          console.log(res.missatge);
          this.buildForm();
          this.router.navigate(['bar-code']);
        }
      });
    }
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }

  //Funció que crea el formulari i les seves validacions.
  private buildForm() {
    this.form = this.formBuilder.group({
      codi: [this.codi, [Validators.required]],
      descripcio: ['', [Validators.required, Validators.maxLength(40)]],
      pes: [
        '',
        [
          Validators.required,
          Validators.maxLength(4),
          Validators.pattern(/^([0-9]\d*$)/),
        ],
      ],
      material: ['', [Validators.required]],
    });
  }
}
