import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { SessioService } from 'src/app/services/sessio.service';
import { DadesService } from 'src/app/services/dades.service';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-dades',
  templateUrl: './dades.page.html',
  styleUrls: ['./dades.page.scss'],
})
export class DadesPage implements OnInit {
  form: any = FormGroup;

  constructor(
    private formBuilder: FormBuilder,
    private sessioService: SessioService,
    private router: Router,
    private dadesService: DadesService,
    private toastController: ToastController
  ) {
    this.buildForm();
  }

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  //Recupera l'usuari abans de carregar la pàgina.
  ionViewWillEnter() {
    this.getDadesUsuari();
  }

  getDadesUsuari() {
    this.dadesService.postUsuari().subscribe((res) => {
      //
      if (!res) {
        this.presentToast('El codi no es troba a la base de dades');

        this.sessioService.openMenu = false;
        this.router.navigate(['sessio']);
      } /*else if (res.status === '0') {
        this.presentToast(res.missatge);
        console.log(res.missatge);
        this.sessioService.openMenu = false;
        this.router.navigate(['sessio']);
      }*/ else if (res.status === '1') {
        this.form.patchValue({
          nif: res.dades[0].nif,
          nom: res.dades[0].nom,
          cognom1: res.dades[0].cognom1,
          cognom2: res.dades[0].cognom2,
          adre: res.dades[0].adre,
          cpostal: res.dades[0].cpostal,
          contra: res.dades[0].contra,
          correu: res.dades[0].correu,
        });
        this.presentToast(res.missatge);
      }
    });
  }

  //Funció que envia el formulari.
  save(event: Event) {
    event.preventDefault();
    if (this.form.valid) {
      const value = this.form.value;
      this.dadesService.putUsuari(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          //console.log(res);
        }
      });
    }
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
  //Funció que crea el formulari i les seves validacions.
  private buildForm() {
    this.form = this.formBuilder.group({
      nif: [
        '',
        [
          Validators.required,
          Validators.minLength(9),
          Validators.maxLength(9),
          Validators.pattern(/^\d{8}[a-zA-Z]$/),
        ],
      ],
      nom: ['', [Validators.required]],
      cognom1: ['', [Validators.required]],
      cognom2: ['', [Validators.required]],
      adre: ['', [Validators.required, Validators.maxLength(50)]],
      cpostal: [
        '',
        [
          Validators.required,
          Validators.minLength(5),
          Validators.maxLength(5),
          Validators.pattern(/^([0-9]\d*$)/),
        ],
      ],
      contra: ['', [Validators.required]],
      correu: ['', [Validators.required]],
    });
  }
}
