import { Component, OnInit } from '@angular/core';
import { SessioService } from 'src/app/services/sessio.service';
import { ManualService } from 'src/app/services/manual.service';
import { ProductesService } from 'src/app/services/productes.service';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-manual',
  templateUrl: './manual.page.html',
  styleUrls: ['./manual.page.scss'],
})
export class ManualPage implements OnInit {
  materialsSC: any = [];
  auxMaterials = 0;
  open = true;
  materials: any[] = [
    { material: 'Paper', color: 'primary' },
    { material: 'Plàstic', color: 'warning' },
    { material: 'Vidre', color: 'success' },
    { material: 'Varis', color: 'danger' },
  ];

  constructor(
    private router: Router,
    private sessioService: SessioService,
    private manualService: ManualService,
    private prodService: ProductesService,
    private toastController: ToastController
  ) {}

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  ionViewWillEnter() {
    this.auxMaterials = 0;
    this.recuperaDades();
  }

  /*Demana a l'API la informació referent a cada material.
  Guarda les dades a l'array d'activitat per a la seva posterior visualització.*/

  recuperaDades() {
    if (this.auxMaterials < this.materials.length) {
      this.manualService
        .postGenerics(this.materials[this.auxMaterials])
        .subscribe((res) => {
          if (res.status === '1') {
            this.presentToast(res.missatge);
            this.materialsSC.splice(this.auxMaterials, 0, res.dades);
            this.auxMaterials++;
            this.recuperaDades();
          }
        });
    }
  }

  //Funció encarregada d'obrir i tancar els diferents desplegables.

  obrirDesplegable(i: any) {
    this.open = true;
    this.materials[i].open = !this.materials[i].open;
  }

  enviarCodi(codi: any) {
    this.prodService.codi = codi;
    this.router.navigate(['no-codi']);
    console.log(codi);
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
}
