import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { ProductesService } from '../../services/productes.service';
import { TemporalService } from 'src/app/services/temporal.service';
import { ManualService } from 'src/app/services/manual.service';
import { Router } from '@angular/router';
import { SessioService } from 'src/app/services/sessio.service';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-no-codi',
  templateUrl: './no-codi.page.html',
  styleUrls: ['./no-codi.page.scss'],
})
export class NoCodiPage implements OnInit {
  form: any = FormGroup;
  codi = '';

  constructor(
    private formBuilder: FormBuilder,
    private prodService: ProductesService,
    private tempService: TemporalService,
    private sessioService: SessioService,
    private manualService: ManualService,
    private router: Router,
    private toastController: ToastController
  ) {
    //Crida a la funció per crear el formulari.
    this.buildForm();
  }

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  //Recupera el codi del servei abans de carregar la pàgina.
  ionViewWillEnter() {
    this.codi = this.prodService.codi;
    //console.log(this.codi);
  }

  //Crida a la funció que envia el codi en entrar a la pàgina.
  ionViewDidEnter() {
    this.enviarCodi();
  }

  /*Envia el codi escanejat al servei, retorna les dades del producte coincident
  amb el codi si aquest existeix a la base de dades i les situa dins del formulari. */
  enviarCodi() {
    const dadesCodi = this.codi;
    this.manualService.getGenerics(dadesCodi).subscribe((res) => {
      if (!res) {
        this.presentToast('El codi no es troba a la base de dades');
        this.sessioService.openMenu = false;
        this.router.navigate(['sessio']);
      } else if (res.status === '1' && res.valor === '0') {
        this.presentToast(res.missatge);
      } else if (res.status === '1') {
        this.presentToast(res.missatge);
        this.form.patchValue({
          codi: this.codi,
          descripcio: res.dades[0].descripcio,
          valor: res.dades[0].valor,
          material: res.dades[0].material,
        });
      }
    });
  }

  //Buida el formulari i torna a la pàgina bar-code amb el botó cancel·lar.
  returnScan() {
    this.router.navigate(['bar-code']);
    this.buildForm();
  }

  /*Funció que envia el formulari omplert prèviament al servei amb les dades rebudes des de la base de dades.
Si la resposta és correcta, ens envia a la pàgina productes-temp que ens mostra els
productes introduïts*/
  save(event: Event) {
    event.preventDefault();
    if (this.form.valid) {
      const value = this.form.value;
      value.pes = value.pes / 1000;
      //console.log(value);
      this.tempService.postProductes(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          console.log(res.missatge);
          this.buildForm();
          this.router.navigate(['productes-temp']);
        }
      });
    }
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }

  //Funció que crea el formulari i les seves validacions.
  private buildForm() {
    this.form = this.formBuilder.group({
      codi: ['', [Validators.required]],
      descripcio: ['', [Validators.required]],
      pes: [
        '',
        [
          Validators.required,
          Validators.maxLength(4),
          Validators.pattern(/^([0-9]\d*$)/),
        ],
      ],
      valor: ['', [Validators.required]],
      material: ['', [Validators.required]],
      quantitat: ['1'],
    });
  }
}
