import { Component, OnInit, ViewChild } from '@angular/core';
import { SessioService } from 'src/app/services/sessio.service';
import { NotificacionsService } from 'src/app/services/notificacions.service';
import { ModalController } from '@ionic/angular';
import { ModalNotificacionsPage } from '../modal-notificacions/modal-notificacions.page';
import { Router } from '@angular/router';
import { IonList } from '@ionic/angular';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-notificacions',
  templateUrl: './notificacions.page.html',
  styleUrls: ['./notificacions.page.scss'],
})
export class NotificacionsPage implements OnInit {
  @ViewChild(IonList) ionList: IonList;

  notificacions: any = [];
  constructor(
    private sessioService: SessioService,
    private notificacionsService: NotificacionsService,
    private router: Router,
    public modalController: ModalController,
    private toastController: ToastController
  ) {}

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  //Crida a l'API i retorna les notificacions en iniciar la pàgina.
  ionViewWillEnter() {
    this.notificacionsService.getNotificacions().subscribe((res) => {
      if (res.status === '1' && res.valor === '0') {
        //console.log(res.missatge);
        this.presentToast(res.missatge);
        this.notificacions = [];
        this.notificacionsService.notificacions = res.noLlegits;
      } else {
        this.notificacions = res.dades;
        this.notificacionsService.notificacions = res.noLlegits;
        //console.log(res.noLlegits);
      }
    });
  }

  //Envia les dades i les presenta a la finestra modal.
  desplegable(i: any) {
    this.presentModal(this.notificacions[i]);
    //console.log(this.notificacions[i]);
    this.llegit(this.notificacions[i]);
  }

  //Funció que marca com a llegit el missatge una vegada obert o amb el botó de llegit.

  llegit(dades: any) {
    const enviarEstat = { id: dades.id, llegit: 'si' };
    //console.log(enviarEstat);
    this.ionList.closeSlidingItems();
    this.notificacionsService
      .postNotificacions(enviarEstat)
      .subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          this.ionViewWillEnter();
          //console.log(res);
        }
      });
  }

  //Funció que permet eliminar les notificacions.
  eliminar(dades: any) {
    //console.log(dades.id);
    const enviarId = { id: dades.id };
    this.ionList.closeSlidingItems();
    this.notificacionsService.deleteNotificacions(enviarId).subscribe((res) => {
      if (res.status === '1') {
        this.presentToast(res.missatge);
        this.ionViewWillEnter();
      }
    });
  }

  //Construeix el modal i envia les dades.

  async presentModal(dades: any) {
    const modal = await this.modalController.create({
      component: ModalNotificacionsPage,
      componentProps: { notificacions: dades },
    });
    await modal.present();
    const { data } = await modal.onWillDismiss();
    if (data.dismissed === true) {
      this.ionViewWillEnter();
      //console.log(data);
    }
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
}
