import { Component, OnInit } from '@angular/core';
import { TemporalService } from 'src/app/services/temporal.service';
import { QrService } from 'src/app/services/qr.service';
import { Router } from '@angular/router';
import {
  BarcodeScannerOptions,
  BarcodeScanner,
} from '@ionic-native/barcode-scanner/ngx';
import { SessioService } from 'src/app/services/sessio.service';
import { ToastController } from '@ionic/angular';
import { ActionSheetController } from '@ionic/angular';

@Component({
  selector: 'app-productes-temp',
  templateUrl: './productes-temp.page.html',
  styleUrls: ['./productes-temp.page.scss'],
})
export class ProductesTempPage implements OnInit {
  llistaTemp = [];
  elementType: 'canvas';
  dadesQR: any;

  barcodeScannerOptions: BarcodeScannerOptions;
  constructor(
    public tempService: TemporalService,
    private sessioService: SessioService,
    private qrService: QrService,
    private router: Router,
    private barcodeScanner: BarcodeScanner,
    private toastController: ToastController,
    public actionSheetController: ActionSheetController
  ) {}

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  //Crida a l'API i retorna els productes en iniciar la pàgina.
  ionViewWillEnter() {
    this.tempService.getProductes().subscribe((res) => {
      if (res.status === '1' && res.valor === '0') {
        console.log(res.missatge);
        this.llistaTemp = [];
      } else {
        this.llistaTemp = res;
      }
    });
  }

  //Crida a l'API i esborra el producte escollit amb el botó eliminar.
  deleteProductes(item: any) {
    this.tempService.deleteProductes(item).subscribe((res) => {
      if (res.status === '1') {
        this.presentToast(res.missatge);
        this.ionViewWillEnter();
      }
    });
  }

  //Crea el codi QR amb un codi aleatori i l'emmagatzema a la base de dades
  crearQR(materialQr: string) {
    const codiValidarQR = Math.floor(Math.random() * (100000 - 10000)) + 10000;
    //console.log(codiValidarQR);
    const valueCodi = { qr: codiValidarQR.toString(), material: materialQr };
    const userId = localStorage.getItem('userId');

    this.qrService.putValidarQR(valueCodi).subscribe((res) => {
      if (res.status === '1') {
        this.qrService.codiValidacioQr =
          'userId=' +
          userId +
          '&codiQr=' +
          codiValidarQR.toString() +
          '&material=' +
          materialQr;
        //console.log(this.qrService.codiValidacioQr.length);
        this.presentToast(res.missatge);
        this.router.navigate(['qr-code']);
      }
    });
  }

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }

  //Crea el desplegable per escollir el material amb el qual crear el codi QR

  async presentActionSheet() {
    const actionSheet = await this.actionSheetController.create({
      header: 'Selecciona el material amb el que vols crear el codi QR',
      buttons: [
        {
          text: 'Paper',
          cssClass: 'paper',
          handler: () => {
            this.crearQR('Paper');
          },
        },
        {
          text: 'Plàstic',
          cssClass: 'plastic',
          handler: () => {
            this.crearQR('Plastic');
          },
        },
        {
          text: 'Vidre',
          cssClass: 'vidre',
          handler: () => {
            this.crearQR('Vidre');
          },
        },
        {
          text: 'Varis',
          cssClass: 'varis',
          handler: () => {
            this.crearQR('Varis');
          },
        },
        {
          text: 'Cancel·lar',
          cssClass: 'cancel',
          role: 'cancel',
          handler: () => {},
        },
      ],
    });
    await actionSheet.present();
  }
}
