import { Component, OnInit } from '@angular/core';
import { ToastController } from '@ionic/angular';
import { PhotoLibrary } from '@ionic-native/photo-library/ngx';
import { SessioService } from 'src/app/services/sessio.service';
import { QrService } from 'src/app/services/qr.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-qr-code',
  templateUrl: './qr-code.page.html',
  styleUrls: ['./qr-code.page.scss'],
})
export class QrCodePage implements OnInit {
  dadesQR: any;
  elementType: any = 'canvas';
  botQr: any = true;
  toast: any;

  constructor(
    private photoLibrary: PhotoLibrary,
    private toastController: ToastController,
    private sessioService: SessioService,
    private qrService: QrService,
    private router: Router
  ) {}

  ngOnInit() {
    if (this.sessioService.openMenu === false) {
      this.router.navigate(['sessio']);
    }
  }

  //Mostra i amaga els botons de la pàgina.
  //Demana el codi de validació al servei per generar el codi QR.
  ionViewWillEnter() {
    this.dadesQR = this.qrService.codiValidacioQr;
    this.botQr = true;
  }

  //Funció que guarda la imatge del codi QR en la galeria del dispositiu.
  guardarQR() {
    const imatge = document.querySelector('canvas') as HTMLCanvasElement;
    const imatgeData = imatge.toDataURL('image/png').toString();

    this.photoLibrary
      .requestAuthorization({ read: true, write: true })
      .then(() => {
        this.photoLibrary
          .saveImage(imatgeData, 'QR')
          .then((res) => {
            this.botQr = false;
            this.presentToast('Imatge guardada a fotos');
          })
          .catch((err) => {
            this.presentToast(err);
          });
      })
      .catch((err) => {
        this.presentToast(err);
      });
  }

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
}
