import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { SessioService } from 'src/app/services/sessio.service';
import { RecuperarService } from 'src/app/services/recuperar.service';
import { DadesService } from 'src/app/services/dades.service';
import { ModContraService } from 'src/app/services/mod-contra.service';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-recuperar',
  templateUrl: './recuperar.page.html',
  styleUrls: ['./recuperar.page.scss'],
})
export class RecuperarPage implements OnInit {
  form: any = FormGroup;
  form1: any = FormGroup;
  form2: any = FormGroup;
  correu: any;
  open1 = true;
  open2 = false;
  open3 = false;

  constructor(
    private formBuilder: FormBuilder,
    private sessioService: SessioService,
    private router: Router,
    private recuperarService: RecuperarService,
    private dadesService: DadesService,
    private modContraService: ModContraService,
    private toastController: ToastController
  ) {
    this.buildForm();
  }

  ngOnInit() {}

  ionViewWillEnter() {
    this.open1 = true;
    this.open2 = false;
    this.open3 = false;

    this.buildForm();
  }

  //Funció que demana a l'API enviar un correu electrònic i generar un codi de validació per recuperar la contrasenya.

  save(event: Event) {
    event.preventDefault();
    if (this.form.valid) {
      const value = this.form.value;
      this.correu = value;
      //console.log(this.correu);
      this.recuperarService.postCorreu(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          this.buildForm1();
          this.buildForm();
          this.open1 = false;
          this.open2 = true;
        }
      });
    }
  }

  //Funció per enviar a l'API el codi de validació rebut per correu electrònic.
  save1(event: Event) {
    event.preventDefault();
    if (this.form1.valid) {
      const value = this.form1.value;
      //console.log(value);
      this.modContraService.postValidacio(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          this.buildForm2();
          this.buildForm1();
          this.open2 = false;
          this.open3 = true;
        }
      });
    }
  }

  //Funció que envia a l'API el formulari amb la nova contrasenya.
  save2(event: Event) {
    event.preventDefault();
    if (this.form2.valid) {
      const value = this.form2.value;
      //console.log(value);
      this.modContraService.putValidacio(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          this.router.navigate(['sessio']);
          //console.log(res);
        }
      });
    }
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
  //Formulari per enviar el correu electrònic.
  private buildForm() {
    this.form = this.formBuilder.group({
      correu: ['', [Validators.required, Validators.email]],
    });
  }

  //Formulari per enviar el codi de validació rebut per correu electrònic.
  private buildForm1() {
    this.form1 = this.formBuilder.group({
      correu: [this.correu.correu, [Validators.required, Validators.email]],
      codiRebut: ['', [Validators.required]],
    });
  }

  //Formulari per canviar la contrasenya i les seves validacions.
  private buildForm2() {
    this.form2 = this.formBuilder.group({
      correu: [this.correu.correu, [Validators.required, Validators.email]],
      contra: ['', [Validators.required]],
    });
  }
}
