import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { RegistreService } from 'src/app/services/registre.service';
import { RegistreCorreuService } from 'src/app/services/registre-correu.service';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-registre',
  templateUrl: './registre.page.html',
  styleUrls: ['./registre.page.scss'],
})
export class RegistrePage implements OnInit {
  form1: any = FormGroup;
  form2: any = FormGroup;
  form3: any = FormGroup;
  open1 = true;
  open2 = false;
  open3 = false;
  correu: any;
  enviar = false;

  constructor(
    private formBuilder: FormBuilder,
    private registreService: RegistreService,
    private registreCorreu: RegistreCorreuService,
    private router: Router,
    private toastController: ToastController
  ) {
    this.buildForm1();
  }

  ngOnInit() {}

  //Funció que demana a l'API enviar un correu electrònic i generar un codi de validació pel registre.
  save1(event: Event) {
    event.preventDefault();
    if (this.form1.valid) {
      const value = this.form1.value;
      this.correu = value;
      //console.log(value);
      this.registreCorreu.putEnviarCorreu(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          //console.log(res.missatge);
          this.buildForm2();
          this.buildForm1();
          this.open1 = false;
          this.open2 = true;
        }
      });
    }
  }

  //Funció per enviar a l'API el codi de validació rebut per correu electrònic.
  save2(event: Event) {
    event.preventDefault();
    if (this.form2.valid) {
      const value = this.form2.value;
      //console.log(value);
      this.registreCorreu.postValidarCorreu(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          //console.log(res.missatge);
          this.buildForm3();
          this.buildForm2();
          this.open2 = false;
          this.open3 = true;
        }
      });
    }
  }

  //Funció que envia a l'API el formulari de registre.
  save3(event: Event) {
    event.preventDefault();
    if (this.form3.valid) {
      const value = this.form3.value;
      //console.log(value);
      this.registreService.postUsuaris(value).subscribe((res) => {
        if (res.status === '1') {
          this.presentToast(res.missatge);
          //console.log(res.missatge);
          this.router.navigate(['sessio']);
        }
      });
    }
  }

  check(event: any) {
    this.enviar = event.detail.checked;
    //console.log(event.detail.checked);
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }

  //Formulari per enviar el correu electrònic.
  private buildForm1() {
    this.form1 = this.formBuilder.group({
      correu: ['', [Validators.required, Validators.email]],
    });
  }

  //Formulari per enviar el codi de validació rebut per correu electrònic.
  private buildForm2() {
    this.form2 = this.formBuilder.group({
      correu: [this.correu.correu, [Validators.required, Validators.email]],
      codiRebut: ['', [Validators.required]],
    });
  }
  //Formulari de registre i les seves validacions.
  private buildForm3() {
    this.form3 = this.formBuilder.group({
      nif: [
        '',
        [
          Validators.required,
          Validators.minLength(9),
          Validators.maxLength(9),
          Validators.pattern(/^\d{8}[a-zA-Z]$/),
        ],
      ],
      nom: ['', [Validators.required, Validators.maxLength(20)]],
      cognom1: ['', [Validators.required, Validators.maxLength(20)]],
      cognom2: ['', [Validators.required, Validators.maxLength(20)]],
      adre: ['', [Validators.required, Validators.maxLength(50)]],
      cpostal: [
        '',
        [
          Validators.required,
          Validators.minLength(5),
          Validators.maxLength(5),
          Validators.pattern(/^([0-9]\d*$)/),
        ],
      ],
      contra: ['', [Validators.required]],
      correu: [this.correu.correu, [Validators.required, Validators.email]],
    });
  }
}
