import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { SessioService } from 'src/app/services/sessio.service';
import { NotificacionsService } from 'src/app/services/notificacions.service';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';

@Component({
  selector: 'app-sessio',
  templateUrl: './sessio.page.html',
  styleUrls: ['./sessio.page.scss'],
})
export class SessioPage implements OnInit {
  form: any = FormBuilder;
  constructor(
    private formBuilder: FormBuilder,
    private sessioService: SessioService,
    private notificacionsService: NotificacionsService,
    private router: Router,
    private toastController: ToastController
  ) {
    this.buildForm();
  }

  ngOnInit() {}

  //Elimina l'usuari i el token guardats abans de carregar la pàgina.
  ionViewWillEnter() {
    this.buildForm();
    localStorage.removeItem('token');
    localStorage.removeItem('userId');
  }

  //Funció que envia el formulari.
  save(event: Event) {
    event.preventDefault();
    if (this.form.valid) {
      const value = this.form.value;
      this.sessioService.postSessio(value).subscribe((res) => {
        //Si retorna el token mostra les opcions privades del menú.
        if (res.status === '1') {
          //console.log(res.token);
          this.sessioService.openMenu = true;
          this.presentToast(res.missatge);
          localStorage.setItem('token', res.token);
          localStorage.setItem('userId', res.userId);
          this.buildForm();
          this.router.navigate(['bar-code']);

          //Demana el nombre de noves notificacions a la base de dades.

          this.notificacionsService.getNotificacions().subscribe((res1) => {
            if (res1.status === '1' && res1.valor === '0') {
              this.presentToast(res.missatge);
              this.notificacionsService.notificacions = res1.noLlegits;
            } else {
              this.notificacionsService.notificacions = res1.noLlegits;
              //console.log(res1.noLlegits);
            }
          });
        } else {
          this.presentToast(res.missatge);
          //console.log(res.missatge);
        }
      });
    }
  }

  //Mostra els missatges de resposta en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
  //Funció que crea el formulari i les seves validacions.
  private buildForm() {
    this.form = this.formBuilder.group({
      usuari: ['', [Validators.required, Validators.email]],
      password: ['', [Validators.required]],
    });
  }
}
