import { Injectable } from '@angular/core';
import {
  HttpInterceptor,
  HttpRequest,
  HttpHandler,
  HttpEvent,
  HttpResponse,
} from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { tap, catchError } from 'rxjs/operators';
import { Router } from '@angular/router';
import { ToastController } from '@ionic/angular';
import { SessioService } from './sessio.service';

@Injectable({
  providedIn: 'root',
})
export class TokenInterceptorService implements HttpInterceptor {
  constructor(
    private router: Router,
    private toastController: ToastController,
    private sessioService: SessioService
  ) {}

  intercept(
    req: HttpRequest<any>,
    next: HttpHandler
  ): Observable<HttpEvent<any>> {
    const tokenUsuari: string = localStorage.getItem('token');
    const user: string = localStorage.getItem('userId');

    //Exclou la crida a l'API per no incloure paràmetres de sol·licitud.
    const excUrl =
      'http://api.mediastack.com/v1/news?access_key=0a222c4954d1df6cf07d242f6caa577a&languages=en&categories=science';
    let request = req;
    //console.log(req.url);

    if (tokenUsuari && req.url !== excUrl) {
      request = req.clone({
        //Introdueix el token en la capçalera de la sol·licitud.
        /*setHeaders: {
          authorization: tokenUsuari,
        },*/
        //Introdueix l'ID del usuari en el body de la sol·licitud.
        body: {
          ...req.body,
          userId: user,
          token: tokenUsuari,
        },
        //Introdueix l'ID del usuari per paràmetres per a les sol·licituds tipus GET.
        setParams: {
          userId: user,
          token: tokenUsuari,
        },
      });
    }
    //console.log(request);
    return next.handle(request).pipe(
      //Captura els errors i mostra un error personalitzat.
      catchError((err) => {
        if (err) {
          localStorage.removeItem('token');
          localStorage.removeItem('userId');
          console.warn(err);
          this.presentToast('Error en resposta servidor\n' + err.message);
          this.router.navigate(['sessio']);
        }

        return throwError('Error en resposta servidor\n' + err.message);
      }),

      //Captura les respostes i mostra els missatges.
      tap((res: any) => {
        if (res instanceof HttpResponse) {
          //En cas que existeixi un body i contingui un status comprova el status retornat.
          if (res.body && res.body.status) {
            //En cas de resposta status 0 de l'API tanca la sessió i retorna a la pàgina d'inici de sessió.
            if (res.body.status === '0') {
              this.presentToast(res.body.missatge);
              this.sessioService.openMenu = false;
              this.router.navigate(['sessio']);
              //console.log(res.body.status);
            }
          }
        }
      })
    );
  }

  //Mostra els missatges en pantalla.

  async presentToast(missatge: any) {
    const toast = await this.toastController.create({
      message: missatge,
      duration: 2000,
      color: 'warning',
    });
    toast.present();
  }
}
